pub struct UrlResolver {
pub base_url: Option<Url>,
}Expand description
Decides which URLs are allowed to be loaded.
Currently only contains the base URL.
The plan is to add: base_only: Only allow to load content from the same base URL. By default include_xml: Allows to use xi:include with XML. Enabled by default. include_text: Allows to use xi:include with text. Enabled by default. local_only: Only allow to load content from the local filesystem. Enabled by default.
Fields
base_url: Option<Url>Base URL; all relative references will be resolved with respect to this.
Implementations
Sourceimpl UrlResolver
impl UrlResolver
Sourcepub fn new(base_url: Option<Url>) -> Self
pub fn new(base_url: Option<Url>) -> Self
Creates a UrlResolver with defaults, and sets the base_url.
Sourcepub fn resolve_href(&self, href: &str) -> Result<AllowedUrl, AllowedUrlError>
pub fn resolve_href(&self, href: &str) -> Result<AllowedUrl, AllowedUrlError>
Decides which URLs are allowed to be loaded based on the presence of a base URL.
This function implements the policy described in “Security and locations of referenced files” in the crate documentation.